sandman.model — sandman 0.9.6 documentation

### Navigation

- index
- modules |
- sandman 0.9.6 documentation »
- Module code »

# Source code for sandman.model

    """The model module is repsonsible exposes the :class:`sandman.model.Model` class,
    from which user models should derive. It also makes the :func:`register`
    function available, which maps endpoints to their associated classes."""

    from sandman.model.utils import register, activate, Model

### Navigation

- index
- modules |
- sandman 0.9.6 documentation »
- Module code »